@@ -1,8 +1,9 @@
+from .bech32 import bech32_decode
 from .invoice import Invoice
 from .onion import OnionPayload, TlvPayload, LegacyOnionPayload
 from .wire import LightningConnection, LightningServerSocket
 
-__version__ = '0.8.2'
+__version__ = '0.8.4'
 
 __all__ = [
     "Invoice",
@@ -11,4 +12,5 @@ __all__ = [
     "OnionPayload",
     "LegacyOnionPayload",
     "TlvPayload",
+    "bech32_decode",
 ]
